====================
django-announcements
====================

Some sites need the ability to broadcast an announcement to all of their
users. django-announcements was created precisely for this reason. How you
present the announcement is up to you as the site-developer. There are two
different types of filtering of announcements:

 * site-wide (this can be presented to anonymous users)
 * members only (announcements for only logged in users)


Development
-----------

The source repository can be found at https://github.com/pinax/django-announcements


Contents
========

.. toctree::
 :maxdepth: 1

 changelog
 installation
 templatetags
 usage
